@@ -74,7 +74,17 @@ class HeaderToLabelMiddleware(object):
         logger.info('', extra=log_entry_info)
 
     def process_response(self, request, response):
+        print("####################################")
+        print("####################################")
+        print("#################0##################")
+        print("####################################")
+        print("####################################")
         headers = Utils.obfuscate_headers(Utils.get_all_headers(request))
+        print("####################################")
+        print("####################################")
+        print("#################1##################")
+        print("####################################")
+        print("####################################")
         status_code = 500
         if hasattr(response, "status_code"):
             status_code = response.status_code
@@ -84,6 +94,11 @@ class HeaderToLabelMiddleware(object):
         else:
             content = str(response)
 
+        print("####################################")
+        print("####################################")
+        print("#################2##################")
+        print("####################################")
+        print("####################################")
         log_entry = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
@@ -98,6 +113,12 @@ class HeaderToLabelMiddleware(object):
         )
         log_entry.update(headers)
 
+        print("####################################")
+        print("####################################")
+        print("#################3##################")
+        print("####################################")
+        print("####################################")
+
         log_entry_info = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
@@ -109,11 +130,22 @@ class HeaderToLabelMiddleware(object):
         log_entry_info.update(log_entry_info)
         log_entry_info.update(headers)
 
+        print("####################################")
+        print("####################################")
+        print("#################4##################")
+        print("####################################")
+        print("####################################")
+
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
         for label in log_label_request_settings:
             log_entry[label] = getattr(request, label)
             log_entry_info[label] = getattr(request, label)
 
+        print("####################################")
+        print("####################################")
+        print("#################5##################")
+        print("####################################")
+        print("####################################")
         if status_code < 400:
             logger.debug(
                 '', extra=log_entry
